@@ -5,9 +5,11 @@ class States(str, Enum):
 
     Off = "off"
     Idle = "idle"
-    Send = "send"
+    InitiateStep = "initiate_step"
+    Initialize = "initialize"
     Monitor = "monitor"
-    Finalize = "finalize"
+    Paused = "paused"
+    StopStep = "stop_step"
 
     def __repr__(self):
         return self.value
