@@ -6,9 +6,17 @@ class RobotCommunicationException(RobotException):
     pass
 
 
+class RobotInfeasibleStepException(RobotException):
+    pass
+
+
 class RobotInvalidResponseException(RobotException):
     pass
 
 
 class RobotMapException(RobotException):
     pass
+
+
+class RobotInvalidTelemetryException(RobotException):
+    pass
